stackit

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 25, 2026 License: MIT Imports: 12 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Client

type Client struct {
	IaaS          *iaas.APIClient
	LoadBalancer  *loadbalancer.APIClient
	Ske           *ske.APIClient
	Redis         *redis.APIClient
	Postgres      *postgres.APIClient
	Mariadb       *mariadb.APIClient
	ObjectStorage *objectstorage.APIClient
}

func NewClient

func NewClient(region string) (*Client, error)

type Prompt

type Prompt struct {
	Parameters *libnuke.Parameters
	ProjectID  string
}

Prompt is a struct that contains the parameters and tenant details use to craft a unique prompt for the user to confirm the nuke operation.

func (*Prompt) Prompt

func (p *Prompt) Prompt() error

Jump to